<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Deepin Image Viewer</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versão:</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>O Deepin Image Viewer é um bonito e fluído gestor de imagens.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Isto tem a função de gerir, visualizar e editar rudimentarmente imagens.   </translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>imagem</translation>
    </message>
    <message>
        <source>images</source>
        <translation>imagens</translation>
    </message>
    <message>
        <source>album</source>
        <translation>album</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>albuns</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Gerir sincronização</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>A sincronizar:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo album</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Sem nome</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Importado recentemente</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Meus favoritos</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Tem a certeza que deseja eliminar este album?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Meus favoritos</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Linha do tempo</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Pode adicionar uma pasta para sincronização ou arrastar e largar as imagens para a linha do tempo</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Sem nome</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Apresentação de Slides</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Deepin Image Viewer</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Imagens</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Tem a certeza que deseja adicionar estas imagens para o album?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Sincronizar e Criar</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Sincronizar</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Tem a certeza que deseja adicionar à lista de sincronização e criar o album com mesmo nome?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Exportado com sucesso</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Falha ao exportar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gravar</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Tem a certeza que deseja enviar as imagens para o LIXO?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Informação da imagem</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Este ficheiro contém várias páginas, por favor use o Evince para ver todas as páginas.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Ecrã inteiro</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Apresentação de Slides</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copiar para área de transferência</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Enviar para o lixo</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Remover do album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Não Favorito</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rodar no sentido dos ponteiros do relógio</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rodar no sentido contrário dos ponteiros do relógio</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Definir como fundo</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar no gestor de ficheiros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informação da imagem</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Pode adicionar uma pasta para sincronização ou arrastar e largar as imagens para a linha do tempo</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Adicionar ao album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Adicionar a um novo album</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Abrir Diretório</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Não tem premissões para ver esta imagem</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Date photoed</source>
        <translation>Data da fotografia</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Data de modificação</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolução</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Tamanho do ficheiro</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espaço de cores</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Modo de exposição</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa de exposição</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tempo de exposição</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Abertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Comprimento focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Abertura máxima</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Modo de medição</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Equilíbrio de brancos</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensação de flash</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modelo da Câmera</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modelo da lente</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Sem escala</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Ajuastar página à imagem</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Ajustar imagem à página</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Escalar por:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milímetros</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centímetros</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Polegadas</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Posição da imagem</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Escalar</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Definições da Imagem</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Estores</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Alternador</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Deslizamento</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Anel</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Selecionar diretório</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Este diretório esta desativado para sincronização</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Adicionar pasta</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Gestor de Sincronização de Diretórios</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>A lista de diretórios está vazia</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Cancelar sincronização</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imagens</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>O dispositivo foi removido</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Este diretório já não existe</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>A calcular...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Visualizador de Imagens</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Ecrã inteiro</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Apresentação de Slides</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Terminar apresentação</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Enviar para o lixo</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Remover do album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Não Favorito</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rodar no sentido dos ponteiros do relógio</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rodar no sentido contrário dos ponteiros do relógio</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Definir como fundo</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar no gestor de ficheiros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informação da imagem</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Seguinte</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Ecrã anterior</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Ecrã seguinte</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostrar atalhos</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Por favor insira um novo atalho</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Atalhos</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Ver Imagem</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Restaurar Predefinições</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Ecrã inteiro</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Apresentação de Slides</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Terminar apresentação</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Enviar para o lixo</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Remover do album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Não Favorito</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rodar no sentido dos ponteiros do relógio</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rodar no sentido contrário dos ponteiros do relógio</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Definir como fundo</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar no gestor de ficheiros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informação da imagem</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>Terminar apresentação</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Pausar/Reproduzir</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Definições de Slides</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Efeito de transição</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duração</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Duração da transição</translation>
    </message>
    <message>
        <source>second</source>
        <translation>segundo</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Gestor de imagens</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Meus favoritos</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Tamanho 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajustar à janela</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rodar contra o sentido dos ponteiros do relógio</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rodas a favor dos ponteiros do relógio</translation>
    </message>
    <message>
        <source>Throw to Trash</source>
        <translation>Atirar para o lixo</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Remover favorito</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Sem ficheiros de imagem encontrados</translation>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 imagem</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 imagens</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Gerir sincronização</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>A sincronizar:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Pode adicionar uma pasta para sincronização ou arrastar e largar as imagens para a linha do tempo</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Adicionar ao album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Adicionar a um novo album</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Ecrã inteiro</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Apresentação de Slides</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copiar para área de transferência</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Enviar para o lixo</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Não Favorito</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rodar no sentido dos ponteiros do relógio</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rodar no sentido contrário dos ponteiros do relógio</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Definir como fundo</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar no gestor de ficheiros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informação da imagem</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Definições de Slides</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Efeito</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duração</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Atalhos</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM aaaa</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Meus favoritos</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Importado recentemente</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Novo album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>O Deepin Image Viewer é um bonito e fluído gestor de imagens.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Tem a função de gerir, visualizar e edição básica de imagens.   </translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Tema Escuro</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Linha do tempo</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Adicionar ao album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Adicionar a um novo album</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Sair do modo ecrã inteiro</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Ecrã inteiro</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Apresentação de Slides</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copiar para área de transferência</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Enviar para o lixo</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Remover do album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Não Favorito</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Mostrar janela de navegação</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Esconder janela de navegação</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rodar no sentido dos ponteiros do relógio</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rodar no sentido contrário dos ponteiros do relógio</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Definir como fundo</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar no gestor de ficheiros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informação da imagem</translation>
    </message>
</context>
</TS>